## Copyright (C) 2004 Eric Chassande-Mottin
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function [tfr,t,f] = dxwv(x,t,fs);
%DWV	cross Wigner-Ville time-frequency dist. as defined by Chassande/Pai
%       Uses the "interlaced" signal.
%	[TFR,T,F]=DXWV(X,T,FS) computes the cross Wigner-Ville distribution
%	of a discrete-time signal X=[X1,X2], 
% 
%	X     : signal
%	T     : time instant(s)          (default : 1:length(X)).
%	FS    : sampling frequency       (default : 1).
%	TFR   : time-frequency representation.
%	F     : vector of normalized frequencies.

if (nargin == 0),
 error('At least one parameter required');
end;

[xrow,xcol] = size(x);
N=xrow;

if (nargin == 1),
  t=1:xrow; fs=1; trace=0;
elseif (nargin == 2),
  fs=1; trace=0;
elseif (nargin ==3),
  trace=0;
end;

[trow,tcol] = size(t);
if (xcol~=2),
  error('X must have two columns');
elseif (trow~=1),
  error('T must only have one row'); 
elseif (2^nextpow2(N)~=N),
  error('N must be a power of two');
end; 

% -- create the interlaced signal and corresponding time vector
N2=2*N;
xi=zeros(N2,2);
xi(1:2:N2-1,:)=x;
xi(2:2:N2,:)=x;
ti=2*t-1;

% -- compute lacf
tfr=lxcf(xi(:,1),xi(:,2),ti);

% -- make FFT
tfr= fft(tfr)/fs;

if (nargout==3),
 f=fs*(0:N2-1)'/N2;
end;

