## Copyright (C) 2004 Eric Chassande-Mottin
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


% -- test code of resample2x.oct

% note: with default interpolation filter,
%
% N_filt=49;p=2;db=-200;
% fmin=0.235; Amin=p; fmax=0.265; Amax=10^(db/20);
% lowpass=remez(2*N_filt,[0 2*fmin 2*fmax 1],[Amin Amin Amax Amax]);
%
% we have distorsion of orginal samples, d1 ~ 10e-11
% and residual signal for f>1/4, d2 ~ 0.07
%

clear;

% -- signal
N=256;
n_trial=10;
x=randn(N,n_trial);

% -- resample signal
y=zeros(2*N,n_trial);
for icol=1:n_trial,
  y(:,icol)=resample2x(x(:,icol));
end;

% -- test1
printf('resample2xt, test1: compare resampled signal to original at odd indices\n');
idx=1:2:2*N-1;
d1=zeros(n_trial,1);
for icol=1:n_trial,
  d1(icol)=max(x(:,icol)-y(idx,icol))/norm(x(:,icol));
end;
d1=mean(d1);
if (abs(d1)>1e-2),
  error('resample2xt: test1 failed');
else
  printf('resample2xt: test1 OK\n');
end;

% -- test2
printf('resample2xt, test2: check that Y(f)~0 for f>1/4\n');
idx=N/2+1:N+1;
d2=zeros(n_trial,1);
for icol=1:n_trial,
  yf=abs(fft(y(:,icol))).^2;
  alias=2*sum(yf(idx));
  tot=sum(yf);
  d2(icol)=sqrt(alias/tot);
end;
d2=mean(d2);
if (d2>1e-1),
  error('resample2xt: test2 failed');
else
  printf('resample2xt: test2 OK\n');
end;
